==> lori_sdk-0.0.1.tar.gz: lib/data/models/order/order.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:lori_sdk/data/models/cart/freight.dart';
import 'package:lori_sdk/data/models/cart/seller.dart';
import 'package:lori_sdk/data/models/cart/paymentMethod.dart';
import 'package:lori_sdk/data/models/order/buyedItem.dart';
import 'package:lori_sdk/data/models/order/orderStep.dart';
import 'package:lori_sdk/data/models/order/paymentInfo.dart';
import 'package:lori_sdk/data/models/userAddress.dart';

part 'order.g.dart';

@JsonSerializable()
class Order {

  Order();

  String id;
  String externalId;

  String createDate;
  String updateDate;
  String nextStepForecast;
  String deliveryForecast;

  Seller seller;

  int status = 0;
  bool isDelivery;

  PaymentInfo paymentInfo;
  UserAddress deliveryAddress;
  Freight freight;
  List<BuyedItem> items;

  List<PaymentMethodType> supportedPaymentMethods;

  //Added this getter as a workaround to support a default value
  //If the API DOES NOT return a supportedPaymentMethods list on the cart the default will be [.credit]
  //But for some reason dart did not allow us to give a list on the defaultValue of the JsonKey...
  List<PaymentMethodType> get supportedPaymentTypes {
    return supportedPaymentMethods == null ? [PaymentMethodType.credit] : supportedPaymentMethods;
  }
  set supportedPaymentTypes(List<PaymentMethodType> methods) {
    if (methods != null) {
      supportedPaymentMethods = methods;
    }
  }

  double subTotalAmount;
  double discountAmount;
  double freightAmount;
  double feeAmount;
  double totalAmount;

  List<OrderStep> steps;

  List<OrderStep> get organizedSteps {
    var organizedSteps = this.steps;
    //Sort the steps
    organizedSteps.sort((stepA, stepB) => stepA.position < stepB.position ? -1 : 1);

    //Find the first step that is on an info level
    var infoStep = organizedSteps.firstWhere((st) => st.level == OrderStep.ORDER_STEP_INFO, orElse: () => null);

    //Check if infoStep is valid
    if (infoStep != null) {
      //Remove all INFO steps that are not the reference infoStep
      organizedSteps = organizedSteps.where((st) => st.position == infoStep.position || st.level != OrderStep.ORDER_STEP_INFO).toList();
    }

    return organizedSteps;
  }

  @JsonKey(ignore: true)
  bool needLoading = false;

  OrderStep bestStepOrder() {
    steps.sort((stepA, stepB) => stepA.position < stepB.position ? -1 : 1);
    if (steps.last.level == OrderStep.ORDER_STEP_ERROR || steps.last.level == OrderStep.ORDER_STEP_SUCCESS) {
      return steps.last;
    } else {
      for (int i = 1; i < steps.length; i++) {
        OrderStep step = steps[i];
        OrderStep previous = steps[i - 1];
        if (previous.level == OrderStep.ORDER_STEP_SUCCESS &&
            (step.level == OrderStep.ORDER_STEP_INFO || step.level == OrderStep.ORDER_STEP_WARNING)) {
          return step;
        }
      }
      return steps.first;
    }
  }

  bool isOrderRetryingPayment() {
    return (paymentInfo.paymentStatus == PaymentInfo.PAYMENT_WAITING_RETRY || paymentInfo.paymentStatus == PaymentInfo.PAYMENT_RETRY_EXPIRED) && bestStepOrder().level != OrderStep.ORDER_STEP_ERROR;
  }

  bool isOrderForPickupPayment() {
    return paymentInfo.paymentStatus == PaymentInfo.PAYMENT_PICKUP_STORE_PAYMENT
        && bestStepOrder().level != OrderStep.ORDER_STEP_ERROR && paymentInfo.hasChangedProgrammatically;
  }

  //If the order does not have an id this means the order is from an external system and does not have an unique identifier
  bool isOrderExternal() {
    return this.id.isEmpty || this.id == "" || this.id == "00000000-0000-0000-0000-000000000000";
  }

  factory Order.fromJson(Map<String, dynamic> json) => _$OrderFromJson(json);
  Map<String, dynamic> toJson() => _$OrderToJson(this);
}

==> lori_sdk-0.0.8.tar.gz: lib/data/models/order/order.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:lori_sdk/data/models/cart/freight.dart';
import 'package:lori_sdk/data/models/cart/paymentMethod.dart';
import 'package:lori_sdk/data/models/cart/seller.dart';
import 'package:lori_sdk/data/models/order/buyedItem.dart';
import 'package:lori_sdk/data/models/order/orderStep.dart';
import 'package:lori_sdk/data/models/order/paymentInfo.dart';
import 'package:lori_sdk/data/models/userAddress.dart';

part 'order.g.dart';

@JsonSerializable()
class Order {
  Order();

  String id;
  String externalId;

  String createDate;
  String updateDate;
  String nextStepForecast;
  String deliveryForecast;

  Seller seller;

  int status = 0;
  bool isDelivery;

  PaymentInfo paymentInfo;
  UserAddress deliveryAddress;
  Freight freight;
  List<BuyedItem> items;

  List<PaymentMethodType> supportedPaymentMethods;

  //Added this getter as a workaround to support a default value
  //If the API DOES NOT return a supportedPaymentMethods list on the cart the default will be [.credit]
  //But for some reason dart did not allow us to give a list on the defaultValue of the JsonKey...
  List<PaymentMethodType> get supportedPaymentTypes {
    return supportedPaymentMethods == null
        ? [PaymentMethodType.credit]
        : supportedPaymentMethods;
  }

  set supportedPaymentTypes(List<PaymentMethodType> methods) {
    if (methods != null) {
      supportedPaymentMethods = methods;
    }
  }

  double subTotalAmount;
  double discountAmount;
  double freightAmount;
  double feeAmount;
  double totalAmount;

  List<OrderStep> steps;

  List<OrderStep> get organizedSteps {
    var organizedSteps = this.steps;
    //Sort the steps
    organizedSteps
        .sort((stepA, stepB) => stepA.position < stepB.position ? -1 : 1);

    //Find the first step that is on an info level
    var infoStep = organizedSteps.firstWhere(
        (st) => st.level == OrderStep.ORDER_STEP_INFO,
        orElse: () => null);

    //Check if infoStep is valid
    if (infoStep != null) {
      //Remove all INFO steps that are not the reference infoStep
      organizedSteps = organizedSteps
          .where((st) =>
              st.position == infoStep.position ||
              st.level != OrderStep.ORDER_STEP_INFO)
          .toList();
    }

    return organizedSteps;
  }

  @JsonKey(ignore: true)
  bool needLoading = false;

  OrderStep bestStepOrder() {
    steps.sort((stepA, stepB) => stepA.position < stepB.position ? -1 : 1);
    if (steps.last.level == OrderStep.ORDER_STEP_ERROR ||
        steps.last.level == OrderStep.ORDER_STEP_SUCCESS) {
      return steps.last;
    } else {
      for (int i = 1; i < steps.length; i++) {
        OrderStep step = steps[i];
        OrderStep previous = steps[i - 1];
        if (previous.level == OrderStep.ORDER_STEP_SUCCESS &&
            (step.level == OrderStep.ORDER_STEP_INFO ||
                step.level == OrderStep.ORDER_STEP_WARNING)) {
          return step;
        }
      }
      return steps.first;
    }
  }

  bool isOrderRetryingPayment() {
    return (paymentInfo.paymentStatus == PaymentInfo.PAYMENT_WAITING_RETRY ||
            paymentInfo.paymentStatus == PaymentInfo.PAYMENT_RETRY_EXPIRED) &&
        bestStepOrder().level != OrderStep.ORDER_STEP_ERROR;
  }

  bool isOrderForPickupPayment() {
    return paymentInfo.paymentStatus ==
            PaymentInfo.PAYMENT_PICKUP_STORE_PAYMENT &&
        bestStepOrder().level != OrderStep.ORDER_STEP_ERROR &&
        paymentInfo.hasChangedProgrammatically;
  }

  //If the order does not have an id this means the order is from an external system and does not have an unique identifier
  bool isOrderExternal() {
    return this.id.isEmpty ||
        this.id == "" ||
        this.id == "00000000-0000-0000-0000-000000000000";
  }

  factory Order.fromJson(Map<String, dynamic> json) => _$OrderFromJson(json);

  Map<String, dynamic> toJson() => _$OrderToJson(this);
}
